"use strict";
/**
 * 数据上报模块
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
    return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reporter = void 0;
var pako_1 = __importDefault(require("pako"));
var Reporter = /** @class */ (function () {
    function Reporter(config) {
        this.debounceTimer = null;
        this.queue = [];
        this.timer = null;
        this.retryCount = 0;
        this.config = {
            reportUrl: config.reportUrl,
            delay: config.delay || 1000,
            maxRetry: config.maxRetry || 3,
            sampleRate: config.sampleRate || 1,
            ignoreUrls: config.ignoreUrls || [],
            compression: config.compression || false
        };
    }
    Reporter.getInstance = function (config) {
        if (!Reporter.instance) {
            if (!config) {
                throw new Error('Reporter configuration is required when creating instance');
            }
            Reporter.instance = new Reporter(config);
        }
        return Reporter.instance;
    };
    /**
     * 添加数据到上报队列
     */
    Reporter.prototype.addToQueue = function (data) {
        var _this = this;
        // 采样率控制
        if (Math.random() > (this.config.sampleRate || 1)) {
            return;
        }
        // URL黑名单过滤
        if (data.type === 'network' && this.isUrlIgnored(data.data.url)) {
            return;
        }
        this.queue.push(data);
        // 清除之前的定时器（如果存在）
        if (this.debounceTimer) {
            clearTimeout(this.debounceTimer);
        }
        // 设置新的定时器
        this.debounceTimer = setTimeout(function () {
            _this.report();
            _this.debounceTimer = null;
        }, this.config.delay);
    };
    /**
     * 执行上报
     */
    Reporter.prototype.report = function () {
        return __awaiter(this, void 0, void 0, function () {
            var dataToReport, payload, jsonString, textEncoder, uint8Array, response, successfullyReportedIds_1, error_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (this.queue.length === 0)
                            return [2 /*return*/];
                        dataToReport = __spreadArray([], this.queue, true);
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        payload = void 0;
                        jsonString = JSON.stringify(dataToReport);
                        if (this.config.compression) {
                            textEncoder = new TextEncoder();
                            uint8Array = textEncoder.encode(jsonString);
                            payload = pako_1.default.gzip(uint8Array);
                        }
                        else {
                            // 不压缩时直接使用JSON字符串
                            payload = jsonString;
                        }
                        return [4 /*yield*/, fetch(this.config.reportUrl, {
                                method: 'POST',
                                headers: {
                                    'Content-Type': this.config.compression
                                        ? 'application/octet-stream'
                                        : 'application/json; charset=UTF-8',
                                    'Content-Encoding': this.config.compression ? 'gzip' : 'identity'
                                },
                                body: payload,
                            })];
                    case 2:
                        response = _a.sent();
                        if (!response.ok) {
                            throw new Error("HTTP Error: ".concat(response.status));
                        }
                        successfullyReportedIds_1 = new Set(dataToReport.map(function (item) { return item.timestamp; }));
                        this.queue = this.queue.filter(function (item) { return !successfullyReportedIds_1.has(item.timestamp); });
                        // 重置重试计数
                        this.retryCount = 0;
                        return [3 /*break*/, 4];
                    case 3:
                        error_1 = _a.sent();
                        // 上报失败时处理错误
                        this.handleReportError(dataToReport, error_1);
                        return [3 /*break*/, 4];
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * 处理上报失败
     */
    Reporter.prototype.handleReportError = function (data, error) {
        var _this = this;
        if (this.retryCount < (this.config.maxRetry || 3)) {
            // 重试延迟时间随重试次数增加
            var retryDelay = Math.pow(2, this.retryCount) * 1000;
            this.retryCount++;
            setTimeout(function () {
                // 将数据重新加入队列
                _this.queue = __spreadArray(__spreadArray([], data, true), _this.queue, true);
            }, retryDelay);
        }
        else {
            // 超过最大重试次数，记录错误
            console.error('Report failed after max retries:', error);
            this.retryCount = 0;
        }
    };
    /**
     * 检查URL是否在忽略列表中
     */
    Reporter.prototype.isUrlIgnored = function (url) {
        return (this.config.ignoreUrls || []).some(function (ignoreUrl) {
            return url.includes(ignoreUrl);
        });
    };
    /**
     * 销毁实例
     */
    Reporter.prototype.destroy = function () {
        if (this.debounceTimer) {
            clearTimeout(this.debounceTimer);
        }
        this.queue = [];
        Reporter.instance = null;
    };
    return Reporter;
}());
exports.Reporter = Reporter;
//# sourceMappingURL=index.js.map